/**
  ******************************************************************************
  * @file    PCF8591.c
  * @brief   This file provides you with control over PCF8591.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; Copyright (c) 2021 STMicroelectronics.
  * All rights reserved.</center></h2>
  *
  * This software component is licensed by ST under BSD 3-Clause license,
  * the "License"; You may not use this file except in compliance with the
  * License. You may obtain a copy of the License at:
  *                        opensource.org/licenses/BSD-3-Clause
  *
  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#include "PCF8591.h"



/******************************************************************************
function:	IICWriteOneByte
parameter: 
    DevAddress: Slave device address
    control:   control word
Info:Write one byte
******************************************************************************/
void IICWriteOneByte(uint8_t DevAddress,uint8_t control) 
{
	HAL_I2C_Master_Transmit(&hi2c1,DevAddress, &control,1,1000);
}



/******************************************************************************
function:	IICWriteTwoByte
parameter: 
    DevAddress: Slave device address
    control:   control word
		D_value: A digital value for conversion to analog voltage
Info:Write two byte
******************************************************************************/
void IICWriteTwoByte(uint8_t DevAddress,uint8_t control,uint8_t D_value) //WriteTwoByte
{
	uint8_t data[2]={0};
	data[0] = control;
	data[1] = D_value;
	HAL_I2C_Master_Transmit(&hi2c1,DevAddress,data,2,100);
}

/******************************************************************************
function:	IICReadOneByte
parameter: 
    DevAddress: Slave device address

Info:Read one byte
******************************************************************************/
uint8_t IICReadOneByte(uint8_t DevAddress)
{
	uint8_t buf[1]={0};	
	HAL_I2C_Master_Receive(&hi2c1,DevAddress,buf,1,1000);
	return buf[0];
}




